==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/structllarp_1_1RouterConfig.md <==
---
title: llarp::RouterConfig

---

# llarp::RouterConfig





## Public Functions

|                | Name           |
| -------------- | -------------- |
| void | **[defineConfigOptions](Classes/structllarp_1_1RouterConfig.md#function-defineconfigoptions)**([ConfigDefinition](Classes/structllarp_1_1ConfigDefinition.md) & conf, const [ConfigGenParameters](Classes/structllarp_1_1ConfigGenParameters.md) & params) |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| size_t | **[m_minConnectedRouters](Classes/structllarp_1_1RouterConfig.md#variable-m-minconnectedrouters)**  |
| size_t | **[m_maxConnectedRouters](Classes/structllarp_1_1RouterConfig.md#variable-m-maxconnectedrouters)**  |
| std::string | **[m_netId](Classes/structllarp_1_1RouterConfig.md#variable-m-netid)**  |
| std::string | **[m_nickname](Classes/structllarp_1_1RouterConfig.md#variable-m-nickname)**  |
| fs::path | **[m_dataDir](Classes/structllarp_1_1RouterConfig.md#variable-m-datadir)**  |
| bool | **[m_blockBogons](Classes/structllarp_1_1RouterConfig.md#variable-m-blockbogons)**  |
| std::optional< [nuint32_t](Classes/structllarp_1_1nuint__t.md) > | **[m_PublicIP](Classes/structllarp_1_1RouterConfig.md#variable-m-publicip)**  |
| [nuint16_t](Classes/structllarp_1_1nuint__t.md) | **[m_PublicPort](Classes/structllarp_1_1RouterConfig.md#variable-m-publicport)**  |
| int | **[m_workerThreads](Classes/structllarp_1_1RouterConfig.md#variable-m-workerthreads)**  |
| int | **[m_numNetThreads](Classes/structllarp_1_1RouterConfig.md#variable-m-numnetthreads)**  |
| size_t | **[m_JobQueueSize](Classes/structllarp_1_1RouterConfig.md#variable-m-jobqueuesize)**  |
| std::string | **[m_routerContactFile](Classes/structllarp_1_1RouterConfig.md#variable-m-routercontactfile)**  |
| std::string | **[m_encryptionKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-encryptionkeyfile)**  |
| std::string | **[m_identityKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-identitykeyfile)**  |
| std::string | **[m_transportKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-transportkeyfile)**  |
| bool | **[m_isRelay](Classes/structllarp_1_1RouterConfig.md#variable-m-isrelay)**  |

## Public Functions Documentation

### function defineConfigOptions

```cpp
void defineConfigOptions(
    ConfigDefinition & conf,
    const ConfigGenParameters & params
)
```


## Public Attributes Documentation

### variable m_minConnectedRouters

```cpp
size_t m_minConnectedRouters = 0;
```


### variable m_maxConnectedRouters

```cpp
size_t m_maxConnectedRouters = 0;
```


### variable m_netId

```cpp
std::string m_netId;
```


### variable m_nickname

```cpp
std::string m_nickname;
```


### variable m_dataDir

```cpp
fs::path m_dataDir;
```


### variable m_blockBogons

```cpp
bool m_blockBogons = false;
```


### variable m_PublicIP

```cpp
std::optional< nuint32_t > m_PublicIP;
```


### variable m_PublicPort

```cpp
nuint16_t m_PublicPort;
```


### variable m_workerThreads

```cpp
int m_workerThreads = -1;
```


### variable m_numNetThreads

```cpp
int m_numNetThreads = -1;
```


### variable m_JobQueueSize

```cpp
size_t m_JobQueueSize = 0;
```


### variable m_routerContactFile

```cpp
std::string m_routerContactFile;
```


### variable m_encryptionKeyFile

```cpp
std::string m_encryptionKeyFile;
```


### variable m_identityKeyFile

```cpp
std::string m_identityKeyFile;
```


### variable m_transportKeyFile

```cpp
std::string m_transportKeyFile;
```


### variable m_isRelay

```cpp
bool m_isRelay = false;
```


-------------------------------

Updated on 2022-05-31 at 02:25:18 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/structllarp_1_1RouterConfig.md <==
---
title: llarp::RouterConfig

---

# llarp::RouterConfig





## Public Functions

|                | Name           |
| -------------- | -------------- |
| void | **[defineConfigOptions](Classes/structllarp_1_1RouterConfig.md#function-defineconfigoptions)**([ConfigDefinition](Classes/structllarp_1_1ConfigDefinition.md) & conf, const [ConfigGenParameters](Classes/structllarp_1_1ConfigGenParameters.md) & params) |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| size_t | **[m_minConnectedRouters](Classes/structllarp_1_1RouterConfig.md#variable-m-minconnectedrouters)**  |
| size_t | **[m_maxConnectedRouters](Classes/structllarp_1_1RouterConfig.md#variable-m-maxconnectedrouters)**  |
| std::string | **[m_netId](Classes/structllarp_1_1RouterConfig.md#variable-m-netid)**  |
| std::string | **[m_nickname](Classes/structllarp_1_1RouterConfig.md#variable-m-nickname)**  |
| fs::path | **[m_dataDir](Classes/structllarp_1_1RouterConfig.md#variable-m-datadir)**  |
| bool | **[m_blockBogons](Classes/structllarp_1_1RouterConfig.md#variable-m-blockbogons)**  |
| int | **[m_workerThreads](Classes/structllarp_1_1RouterConfig.md#variable-m-workerthreads)**  |
| int | **[m_numNetThreads](Classes/structllarp_1_1RouterConfig.md#variable-m-numnetthreads)**  |
| size_t | **[m_JobQueueSize](Classes/structllarp_1_1RouterConfig.md#variable-m-jobqueuesize)**  |
| std::string | **[m_routerContactFile](Classes/structllarp_1_1RouterConfig.md#variable-m-routercontactfile)**  |
| std::string | **[m_encryptionKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-encryptionkeyfile)**  |
| std::string | **[m_identityKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-identitykeyfile)**  |
| std::string | **[m_transportKeyFile](Classes/structllarp_1_1RouterConfig.md#variable-m-transportkeyfile)**  |
| bool | **[m_isRelay](Classes/structllarp_1_1RouterConfig.md#variable-m-isrelay)**  |
| std::optional< net::ipaddr_t > | **[PublicIP](Classes/structllarp_1_1RouterConfig.md#variable-publicip)** <br>deprecated  |
| std::optional< net::port_t > | **[PublicPort](Classes/structllarp_1_1RouterConfig.md#variable-publicport)** <br>deprecated  |

## Public Functions Documentation

### function defineConfigOptions

```cpp
void defineConfigOptions(
    ConfigDefinition & conf,
    const ConfigGenParameters & params
)
```


## Public Attributes Documentation

### variable m_minConnectedRouters

```cpp
size_t m_minConnectedRouters = 0;
```


### variable m_maxConnectedRouters

```cpp
size_t m_maxConnectedRouters = 0;
```


### variable m_netId

```cpp
std::string m_netId;
```


### variable m_nickname

```cpp
std::string m_nickname;
```


### variable m_dataDir

```cpp
fs::path m_dataDir;
```


### variable m_blockBogons

```cpp
bool m_blockBogons = false;
```


### variable m_workerThreads

```cpp
int m_workerThreads = -1;
```


### variable m_numNetThreads

```cpp
int m_numNetThreads = -1;
```


### variable m_JobQueueSize

```cpp
size_t m_JobQueueSize = 0;
```


### variable m_routerContactFile

```cpp
std::string m_routerContactFile;
```


### variable m_encryptionKeyFile

```cpp
std::string m_encryptionKeyFile;
```


### variable m_identityKeyFile

```cpp
std::string m_identityKeyFile;
```


### variable m_transportKeyFile

```cpp
std::string m_transportKeyFile;
```


### variable m_isRelay

```cpp
bool m_isRelay = false;
```


### variable PublicIP

```cpp
std::optional< net::ipaddr_t > PublicIP;
```

deprecated 

### variable PublicPort

```cpp
std::optional< net::port_t > PublicPort;
```

deprecated 

-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
